use crate::{schema, UIDCError};
use microrm::prelude::*;

pub trait ClientExt {
    fn client_instance(&self) -> &schema::Client;

    fn check_redirect(&self, uri: &str) -> Result<bool, UIDCError> {
        for redirect in self.client_instance().redirects.get()?.into_iter() {
            let pattern = glob::Pattern::new(redirect.redirect_pattern.as_str())
                .map_err(|_| UIDCError::Abort("couldn't parse redirect URI as glob pattern"))?;
            if pattern.matches(uri) {
                return Ok(true);
            }
        }
        Ok(false)
    }
}

impl ClientExt for schema::Client {
    fn client_instance(&self) -> &schema::Client {
        self
    }
}
